@@ -19,7 +19,7 @@ from typing import IO, Any, Dict, Mapping, Sequence, Type, Union, overload
 from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
 
-from .literals import EnhancedMonitoringType
+from .literals import EnhancedMonitoringType, StorageModeType
 from .paginator import (
     ListClusterOperationsPaginator,
     ListClustersPaginator,
@@ -64,6 +64,7 @@ from .type_defs import (
     LoggingInfoTypeDef,
     OpenMonitoringInfoTypeDef,
     ProvisionedRequestTypeDef,
+    ProvisionedThroughputTypeDef,
     RebootBrokerResponseTypeDef,
     ServerlessRequestTypeDef,
     UpdateBrokerCountResponseTypeDef,
@@ -75,6 +76,7 @@ from .type_defs import (
     UpdateConnectivityResponseTypeDef,
     UpdateMonitoringResponseTypeDef,
     UpdateSecurityResponseTypeDef,
+    UpdateStorageResponseTypeDef,
 )
 
 if sys.version_info >= (3, 9):
@@ -172,7 +174,8 @@ class KafkaClient(BaseClient):
         EnhancedMonitoring: EnhancedMonitoringType = ...,
         OpenMonitoring: OpenMonitoringInfoTypeDef = ...,
         LoggingInfo: LoggingInfoTypeDef = ...,
-        Tags: Mapping[str, str] = ...
+        Tags: Mapping[str, str] = ...,
+        StorageMode: StorageModeType = ...
     ) -> CreateClusterResponseTypeDef:
         """
         Creates a new MSK cluster.
@@ -547,6 +550,22 @@ class KafkaClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kafka/client/#update_security)
         """
 
+    def update_storage(
+        self,
+        *,
+        ClusterArn: str,
+        CurrentVersion: str,
+        ProvisionedThroughput: ProvisionedThroughputTypeDef = ...,
+        StorageMode: StorageModeType = ...,
+        VolumeSizeGB: int = ...
+    ) -> UpdateStorageResponseTypeDef:
+        """
+        Updates cluster broker volume size (or) sets cluster storage mode to TIERED.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Client.update_storage)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kafka/client/#update_storage)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_cluster_operations"]
